==> ksystemlog-18.08.2.tar.xz: ksystemlog-18.08.2/src/modes/xorg/xorgConfigurationWidget.h <==
/***************************************************************************
 *   KSystemLog, a system log viewer tool                                  *
 *   Copyright (C) 2007 by Nicolas Ternisien                               *
 *   nicolas.ternisien@gmail.com                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
 ***************************************************************************/

#ifndef _XORG_CONFIGURATION_WIDGET_H_
#define _XORG_CONFIGURATION_WIDGET_H_

#include <KLocalizedString>

#include "globals.h"
#include "logging.h"
#include "fileList.h"

#include "logLevel.h"
#include "logModeConfigurationWidget.h"

#include "xorgConfiguration.h"
#include "xorgLogMode.h"

class FileList;

class XorgConfigurationWidget : public LogModeConfigurationWidget
{
    Q_OBJECT

public:
    XorgConfigurationWidget()
        : LogModeConfigurationWidget(i18n("X.org Log"), QStringLiteral(XORG_MODE_ICON), i18n("X.org Log"))
    {
        QHBoxLayout *layout = new QHBoxLayout();
        this->setLayout(layout);

        fileList
            = new FileList(this, i18n("<p>These files will be analyzed to show the <b>X.org log</b>.</p>"));
        connect(fileList, &FileList::fileListChanged, this, &LogModeConfigurationWidget::configurationChanged);
        layout->addWidget(fileList);
    }

    ~XorgConfigurationWidget() {}

public slots:

    void saveConfig() Q_DECL_OVERRIDE
    {
        XorgConfiguration *xorgConfiguration = Globals::instance()
                                                   .findLogMode(QStringLiteral(XORG_LOG_MODE_ID))
                                                   ->logModeConfiguration<XorgConfiguration *>();

        xorgConfiguration->setXorgPaths(fileList->paths());
    }

    void readConfig() Q_DECL_OVERRIDE
    {
        XorgConfiguration *xorgConfiguration = Globals::instance()
                                                   .findLogMode(QStringLiteral(XORG_LOG_MODE_ID))
                                                   ->logModeConfiguration<XorgConfiguration *>();

        fileList->removeAllItems();

        fileList->addPaths(xorgConfiguration->xorgPaths());
    }

    void defaultConfig() Q_DECL_OVERRIDE
    {
        // TODO Find a way to read the configuration per default
        readConfig();
    }

protected:
    bool isValid() const Q_DECL_OVERRIDE
    {
        if (fileList->isEmpty() == false) {
            return true;
        }

        return false;
    }

private:
    FileList *fileList;
};

#endif // _XORG_CONFIGURATION_WIDGET_H_

==> ksystemlog-21.04.1.tar.xz: ksystemlog-21.04.1/src/modes/xorg/xorgConfigurationWidget.h <==
/***************************************************************************
 *   KSystemLog, a system log viewer tool                                  *
 *   Copyright (C) 2007 by Nicolas Ternisien                               *
 *   nicolas.ternisien@gmail.com                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
 ***************************************************************************/

#ifndef XORG_CONFIGURATION_WIDGET_H
#define XORG_CONFIGURATION_WIDGET_H

#include <KLocalizedString>

#include "fileList.h"
#include "globals.h"
#include "logging.h"

#include "logLevel.h"
#include "logModeConfigurationWidget.h"

#include "xorgConfiguration.h"
#include "xorgLogMode.h"

class FileList;

class XorgConfigurationWidget : public LogModeConfigurationWidget
{
    Q_OBJECT

public:
    XorgConfigurationWidget();

    ~XorgConfigurationWidget() override
    {
    }

public Q_SLOTS:

    void saveConfig() override;

    void readConfig() override;

    void defaultConfig() override;

protected:
    bool isValid() const override;

private:
    FileList *mFileList = nullptr;
};

#endif // _XORG_CONFIGURATION_WIDGET_H
